@@ -7,7 +7,6 @@
 #' @param  dest A temporary directory where a csv file is downloaded before being read into memory
 #' @param  ... Additional arguments into \code{read.csv}
 #' @template token
-#' @importFrom utils read.csv
 #' @export
 #' @examples \dontrun{
 #' write.csv(iris, file = "iris.csv")
@@ -17,6 +16,6 @@
 #'}
 drop_read_csv <- function(file, dest = tempdir(), dtoken = get_dropbox_token(), ...) {
     localfile = paste0(dest, "/", basename(file))
-    drop_get(file, local_file = localfile, overwrite = TRUE, dtoken = dtoken)
-    read.csv(localfile, ...)
+    drop_download(file, localfile, overwrite = TRUE, dtoken = dtoken)
+    utils::read.csv(localfile, ...)
 }
